---
# SPDX-FileCopyrightText: 2024 Nicco Kunzmann and Open Web Calendar Contributors <https://open-web-calendar.quelltext.eu/>
#
# SPDX-License-Identifier: CC-BY-SA-4.0

description: How to report security concerns about the Open Web Calendar project.
---

# Security Policy

## Supported Versions

Only the `master` branch receives security updates.
When an security update is made, it is released with the [latest version](../changelog).

| Version       | Supported          |
| ------------- | ------------------ |
| master        |       ✅           |
| anything else |       ❌           |

## Reporting a Vulnerability

If you find a security vulnerability, please report it to the developer
[@niccokunzmann](https://github.com/niccokunzmann/) or
open an issue if you think it is a minor thread.
